# dsnd-distributions package

Contains:
- General distribution 
- Gaussian ditribution
- Binomial distribution

# Files
- README.md - dscription-file
- license.txt - license file
- setup.cfg - metadata about README.md file
- setup.py - name and disttribution of file
- gauss_binom_kwo - modules